# Generated by Django 2.1.9 on 2019-06-11 21:34

import django.core.files.storage
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("legislative", "0008_longer_event_name"),
        ("councilmatic_core", "0045_auto_20190513_1250"),
    ]

    operations = [
        migrations.CreateModel(
            name="BillDocument",
            fields=[
                (
                    "document",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="councilmatic_document",
                        serialize=False,
                        to="legislative.BillDocument",
                    ),
                ),
                ("full_text", models.TextField(blank=True, null=True)),
            ],
            options={
                "abstract": False,
            },
            bases=("legislative.billdocument",),
        ),
        migrations.AlterField(
            model_name="person",
            name="headshot",
            field=models.FileField(
                default="images/headshot_placeholder.png",
                storage=django.core.files.storage.FileSystemStorage(
                    base_url="/",
                    location="/Users/hannah/projects/chi-councilmatic/chicago/static",
                ),
                upload_to="images",
            ),
        ),
    ]
